%define major         11
%define gpgmepp_major 6
%define qgpgme_major  15

%define libname       %mklibname gpgme %{major}
%define libgpgmepp    %mklibname gpgmepp %{gpgmepp_major}
%define develname     %mklibname gpgme -d

### Qt5
%define libqgpgme     %mklibname qgpgme %{qgpgme_major}
%define qdevname      %mklibname qgpgme -d

### Qt6
%define libqgpgmeqt6  %mklibname qgpgmeqt6_ %{qgpgme_major}
%define qdevnameqt6   %mklibname qgpgme-qt6 -d

%bcond_without qt6

Summary:	GnuPG Made Easy (GPGME)
Name:		gpgme
Version:	1.23.2
Release:	%mkrel 4
License:	LGPLv2+
Group:		File tools
URL:		https://www.gnupg.org/gpgme.html
Source0:	https://gnupg.org/ftp/gcrypt/gpgme/%{name}-%{version}.tar.bz2
Source1:	https://gnupg.org/ftp/gcrypt/gpgme/%{name}-%{version}.tar.bz2.sig

## upstream patches

## downstream patches
# Don't add extra libs/cflags in gpgme-config/cmake equivalent
Patch1001:      0001-don-t-add-extra-libraries-for-linking.patch
# add -D_FILE_OFFSET_BITS... to gpgme-config, upstreamable
Patch1002:      gpgme-1.3.2-largefile.patch
# Avoid to generate python package containing -unknown in its version number, not conform
# https://launchpadlibrarian.net/605313938/0001-avoid-identifying-as-beta-FIXED.patch
Patch1003:      0001-avoid-identifying-as-beta-FIXED.patch
# Allow extra options to be passed to setup.py during installation
Patch1004:      0002-setup_py_extra_opts.patch

BuildRequires:	autoconf-archive
# support for Cryptographic Message Syntax protocol
BuildRequires:	gnupg2
BuildRequires:	pkgconfig(libassuan)
BuildRequires:	pkgconfig(gpg-error)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Test)
%if %{with qt6}
BuildRequires:	makeinfo
BuildRequires:	pkgconfig(Qt6Core)
BuildRequires:	pkgconfig(Qt6Test)
%endif
BuildRequires:	doxygen
BuildRequires:	graphviz
# Automatic provides generation for devel subpackage
BuildRequires:	cmake-rpm-macros
# Build dependencies for Python subpackages
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)
# Needed since Python 3.12+ drops distutils
BuildRequires:	python3-setuptools

%description
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libname}
Summary:	GnuPG Made Easy (GPGME)
Group:		System/Libraries
# support for Cryptographic Message Syntax protocol
Requires:	gnupg2
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

%package -n %{libgpgmepp}
Summary:	GpgME++ - C++ bindings/wrapper for gpgme
Group:		System/Libraries

%description -n %{libgpgmepp}
GpgME++ - C++ bindings/wrapper for gpgme.

### Qt5
%package -n %{libqgpgme}
Summary:	QGpgME - Qt5 bindings/wrapper for gpgme
Group:		System/Libraries
License:	GPLv2+

%description -n %{libqgpgme}
QGpgME - Qt5 bindings/wrapper for gpgme.

### Qt6
%package -n %{libqgpgmeqt6}
Summary:	QGpgME - Qt6 bindings/wrapper for gpgme
Group:		System/Libraries
License:	GPLv2+

%description -n %{libqgpgmeqt6}
QGpgME - Qt6 bindings/wrapper for gpgme.

%package -n %{develname}
Summary:	GnuPG Made Easy (GPGME) Header files and libraries for development
Group:		Development/C
License:	LGPLv2+
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libgpgmepp} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
gpgme library for crypto awareness.

### Qt5
%package -n %{qdevname}
Summary:        Qt5 GnuPG Made Easy (GPGME) Header files and libraries for development
Group:          Development/C
License:        GPLv2+
Requires:       %{libqgpgme} = %{version}-%{release}
Provides:       q%{name}-devel = %{version}-%{release}
Provides:       libq%{name}-devel = %{version}-%{release}
Conflicts:      %{_lib}%{name}-devel < 1.17.1-3

%description -n %{qdevname}
Qt5 GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
qgpgme library for crypto awareness.

### Qt6
%package -n %{qdevnameqt6}
Summary:        Qt6 GnuPG Made Easy (GPGME) Header files and libraries for development
Group:          Development/C
License:        GPLv2+
Requires:       %{libqgpgmeqt6} = %{version}-%{release}
Provides:       q%{name}-qt6-devel = %{version}-%{release}
Provides:       libq%{name}-qt6-devel = %{version}-%{release}

%description -n %{qdevnameqt6}
Qt6 GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG easier
for applications.

Install this package if you want to develop applications that will use the
qgpgme library for crypto awareness.

%package -n python3-gpg
Summary:	GnuPG Made Easy (GPGME) bindings for Python 3
Group:		Development/Python
License:	GPLv2+
%{?python_provide:%python_provide python3-gpg}
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description -n python3-gpg
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications.

This package provides bindings to %{name} libraries for Python 3.

%prep
%autosetup -p1

# Force GPG2
find -type f -name Makefile\* -exec sed -i -e 's|GPG = gpg2\?|GPG = gpg2|' {} ';'

# Use ax_python_devel.m4 from autoconf-archive
rm -rf m4/ax_python_devel.m4

# use python.m4 from automake
rm -rf m4/python.m4

%if %{with qt6}
# Building qt5 and qt6 bindings in the same source tree is not supported
cp -r . %{_builddir}/%{name}-%{version}-qt6
%endif

%build
export PATH=%{_qt5_bindir}:$PATH
export SETUPTOOLS_USE_DISTUTILS=local

# Fix qgpgme build on 32bit arches
export CPPFLAGS='-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

%configure \
	--enable-languages=cpp,qt,python,cl \
	--disable-static \
	--disable-gpgsm-test \
	--with-libassuan-prefix=%{_prefix}
%make_build

%if %{with qt6}
cd %{_builddir}/%{name}-%{version}-qt6
export PATH=%{_qt6_bindir}:$PATH

%configure \
	--enable-languages=cpp,qt6 \
	--disable-static \
	--disable-gpgsm-test \
	--with-libassuan-prefix=%{_prefix}
%make_build
%endif

%install
# When using distutils from setuptools 60+, ./setup.py install use
# the .egg format. This forces setuptools to use .egg-info format.
# SETUP_PY_EXTRA_OPTS is introduced by the Patch1004 above.
export SETUPTOOLS_USE_DISTUTILS=local
export SETUP_PY_EXTRA_OPTS="--single-version-externally-managed --root=/"
%make_install

%if %{with qt6}
cd %{_builddir}/%{name}-%{version}-qt6
%make_install
%endif

#we don't want these
find %{buildroot} -name "*.la" -delete

# autofoo installs useless stuff for uninstall
rm -vf %{buildroot}%{python3_sitelib}/gpg/install_files.txt

# all tests must pass
%check
# https://dev.gnupg.org/T3920
make check || :

%files -n %{libname}
%license COPYING*
%{_libdir}/libgpgme.so.%{major}{,.*}

%files -n %{libgpgmepp}
%doc lang/cpp/README
%{_libdir}/libgpgmepp.so.%{gpgmepp_major}{,.*}

### Qt5
%files -n %{libqgpgme}
%{_libdir}/libqgpgme.so.%{qgpgme_major}{,.*}

### Qt6
%files -n %{libqgpgmeqt6}
%{_libdir}/libqgpgmeqt6.so.%{qgpgme_major}{,.*}

%files -n %{develname}
%doc AUTHORS ChangeLog NEWS README THANKS TODO
%{_bindir}/gpgme-config
%{_bindir}/gpgme-json
%{_bindir}/gpgme-tool
%{_libdir}/libgpgme.so
%{_libdir}/libgpgmepp.so
%{_libdir}/pkgconfig/gpgme.pc
%{_libdir}/pkgconfig/gpgme-glib.pc
%{_datadir}/aclocal/*.m4
%{_includedir}/gpgme++/
%{_includedir}/gpgme.h
%{_infodir}/gpgme.info*
%dir %{_datadir}/common-lisp/source/gpgme
%{_datadir}/common-lisp/source/gpgme/gpgme-package.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme.asd
%{_datadir}/common-lisp/source/gpgme/gpgme.lisp
%{_datadir}/common-lisp/source/gpgme/gpgme-grovel.lisp
%{_libdir}/cmake/Gpgmepp/

### Qt5
%files -n %{qdevname}
%{_includedir}/QGpgME/
%{_includedir}/qgpgme/
%{_libdir}/cmake/QGpgme/
%{_libdir}/libqgpgme.so

### Qt6
%files -n %{qdevnameqt6}
%{_includedir}/QGpgME/
%{_includedir}/qgpgme/
%{_libdir}/cmake/QGpgmeQt6/
%{_libdir}/libqgpgmeqt6.so

%files -n python3-gpg
%doc lang/python/README
%{python3_sitearch}/gpg-*.egg-info
%{python3_sitearch}/gpg/


%changelog
* Thu Jul 04 2024 wally <wally> 1.23.2-4.mga10
+ Revision: 2079626
- rebuild for libassuan 3.0.1

* Fri Dec 29 2023 papoteur <papoteur> 1.23.2-3.mga10
+ Revision: 2024345
- rebuild for python 3.12

* Wed Dec 20 2023 daviddavid <daviddavid> 1.23.2-2.mga10
+ Revision: 2020140
- rebuild for py3.12

* Thu Dec 07 2023 daviddavid <daviddavid> 1.23.2-1.mga10
+ Revision: 2014832
- new version: 1.23.2

* Thu Nov 02 2023 daviddavid <daviddavid> 1.23.1-1.mga10
+ Revision: 2003519
- new version: 1.23.1

* Fri Oct 27 2023 daviddavid <daviddavid> 1.23.0-1.mga10
+ Revision: 2002136
- new version: 1.23.0

* Mon Sep 18 2023 daviddavid <daviddavid> 1.20.0-1.mga10
+ Revision: 1987806
- new version: 1.20.0
- enable Qt6 support

* Sun Sep 18 2022 papoteur <papoteur> 1.18.0-1.mga9
+ Revision: 1889761
- new 1.18.0
- Avoid to generate python package containing -unknown in its version number

* Mon Aug 08 2022 mrambo3501 <mrambo3501> 1.17.1-5.mga9
+ Revision: 1876124
- use Python's bundled distutils

* Sun Aug 07 2022 mrambo3501 <mrambo3501> 1.17.1-4.mga9
+ Revision: 1875999
- fix filelists

* Sat Apr 23 2022 wally <wally> 1.17.1-3.mga9
+ Revision: 1852950
- split out QGpgme devel
- fix licenses

* Mon Apr 04 2022 umeabot <umeabot> 1.17.1-2.mga9
+ Revision: 1842949
- Mageia 9 Mass Rebuild
+ wally <wally>
- new version 1.17.1
- new qgpgme major 15

* Sun Feb 06 2022 wally <wally> 1.16.0-2.mga9
+ Revision: 1772241
- add patches from Fedora
- rebuild for python3.10
- rebuild for python3.10

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1.16.0-1.mga9
+ Revision: 1740189
- 1.16.0

* Mon Mar 15 2021 wally <wally> 1.15.1-2.mga9
+ Revision: 1703315
- rebuild for python 3.9

* Tue Mar 02 2021 daviddavid <daviddavid> 1.15.1-1.mga9
+ Revision: 1696089
- new version: 1.15.1

* Wed Dec 16 2020 umeabot <umeabot> 1.15.0-2.mga8
+ Revision: 1658502
- Rebuild for new Qt5

* Wed Nov 18 2020 luigiwalser <luigiwalser> 1.15.0-1.mga8
+ Revision: 1647114
- 1.15.0

* Thu Aug 20 2020 ovitters <ovitters> 1.14.0-2.mga8
+ Revision: 1616646
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Sat Jul 18 2020 daviddavid <daviddavid> 1.14.0-1.mga8
+ Revision: 1607139
- new version: 1.14.0

* Thu Apr 16 2020 joequant <joequant> 1.13.1-5.mga8
+ Revision: 1567833
- increment version
- move recommends back to requires

* Wed Apr 15 2020 joequant <joequant> 1.13.1-4.mga8
+ Revision: 1567450
- change including executable to recommends to reduce container bloat

* Sun Feb 16 2020 umeabot <umeabot> 1.13.1-3.mga8
+ Revision: 1531002
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 08 2019 wally <wally> 1.13.1-2.mga8
+ Revision: 1438401
- fix build with python3.8
- rebuild for python3.8
- drop python2 support

* Thu Jul 04 2019 daviddavid <daviddavid> 1.13.1-1.mga8
+ Revision: 1418284
- new version: 1.13.1

* Sat Apr 13 2019 daviddavid <daviddavid> 1.13.0-1.mga7
+ Revision: 1389639
- new version: 1.13.0

* Sat Mar 30 2019 umeabot <umeabot> 1.12.0-3.mga7
+ Revision: 1381821
- Qt5 Rebuild

* Sat Jan 05 2019 wally <wally> 1.12.0-2.mga7
+ Revision: 1349795
- rebuild for python3.7

* Wed Oct 31 2018 wally <wally> 1.12.0-1.mga7
+ Revision: 1326971
- new version 1.12.0
- drop multiarch support

* Sun Sep 23 2018 umeabot <umeabot> 1.11.1-2.mga7
+ Revision: 1298045
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 wally <wally> 1.11.1-1.mga7
+ Revision: 1221048
- new version 1.11.1

* Thu Apr 19 2018 daviddavid <daviddavid> 1.11.0-1.mga7
+ Revision: 1220137
- new version: 1.11.0
- requires now gpg-error >= 1.29

* Mon Feb 26 2018 daviddavid <daviddavid> 1.10.0-1.mga7
+ Revision: 1205324
- new version: 1.10.0
- remove merged upstream patch

* Mon Feb 26 2018 daviddavid <daviddavid> 1.9.0-2.mga7
+ Revision: 1205294
- remove no more needed BR libpth-devel

* Wed Nov 01 2017 mjack <mjack> 1.9.0-1.mga7
+ Revision: 1175310
- Updated to version 1.9.0
- Patched sources to get rid of format security errors
- Updated with proper buildrequires

* Fri Aug 04 2017 tv <tv> 1.8.0-12.mga7
+ Revision: 1134538
- rebuild for new python

* Thu Mar 23 2017 ngompa <ngompa> 1.8.0-11.mga6
+ Revision: 1094591
- Bump rel to try build again
- Add missing python-gpg Provides to python2-gpg

* Sat Mar 11 2017 ngompa <ngompa> 1.8.0-9.mga6
+ Revision: 1091942
- Ensure gpgme uses gpg2 consistently
- Add missing Python bindings
- Add patch from Fedora

* Fri Dec 16 2016 daviddavid <daviddavid> 1.8.0-8.mga6
+ Revision: 1075639
- Obsolete also kf5gpgmepp5

* Thu Dec 15 2016 neoclust <neoclust> 1.8.0-7.mga6
+ Revision: 1075479
- Obsolete kf5gpgme-devel and kf5gpgme5

* Thu Dec 15 2016 rapsys <rapsys> 1.8.0-6.mga6
+ Revision: 1075308
- Rebuild

* Wed Dec 14 2016 neoclust <neoclust> 1.8.0-5.mga6
+ Revision: 1075046
- Add obsoletes to ease upgrade

* Tue Dec 13 2016 daviddavid <daviddavid> 1.8.0-3.mga6
+ Revision: 1074735
- submit to release

* Sat Dec 10 2016 daviddavid <daviddavid> 1.8.0-2.mga6
+ Revision: 1073941
- add an upstream patch to remove a forgotten instance of @libsuffix@

* Sat Dec 10 2016 daviddavid <daviddavid> 1.8.0-1.mga6
+ Revision: 1073923
- new version: 1.8.0 (fixes some bugs for the kde apps 16.12 stack)
- remove merged upstream patch

* Fri Dec 09 2016 daviddavid <daviddavid> 1.7.1-4.mga6
+ Revision: 1073909
- add patch to fix the Qt cmake config files install path

* Thu Dec 08 2016 neoclust <neoclust> 1.7.1-3.mga6
+ Revision: 1073180
- Fix conflicts over kdepimlibs

* Wed Dec 07 2016 neoclust <neoclust> 1.7.1-2.mga6
+ Revision: 1073016
- Enable qt binding

* Wed Dec 07 2016 neoclust <neoclust> 1.7.1-1.mga6
+ Revision: 1073009
- New version 1.7.1

* Mon Feb 15 2016 umeabot <umeabot> 1.6.0-2.mga6
+ Revision: 960515
- Mageia 6 Mass Rebuild

* Tue Oct 13 2015 fwang <fwang> 1.6.0-1.mga6
+ Revision: 890206
- 1.6.0

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.5.5-1.mga6
+ Revision: 837378
- fix files list
- 1.5.5

* Wed Oct 15 2014 umeabot <umeabot> 1.5.1-3.mga5
+ Revision: 739807
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.5.1-2.mga5
+ Revision: 679909
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 luigiwalser <luigiwalser> 1.5.1-1.mga5
+ Revision: 658699
- 1.5.1 (fixes CVE-2014-3564)

* Thu Jul 10 2014 luigiwalser <luigiwalser> 1.5.0-1.mga5
+ Revision: 651124
- 1.5.0

* Sat Oct 19 2013 umeabot <umeabot> 1.4.3-2.mga4
+ Revision: 532359
- Mageia 4 Mass Rebuild

* Tue Aug 20 2013 sander85 <sander85> 1.4.3-1.mga4
+ Revision: 468097
- New version: 1.4.3

* Sun Jul 07 2013 luigiwalser <luigiwalser> 1.4.2-1.mga4
+ Revision: 450796
- 1.4.2

* Wed May 29 2013 guillomovitch <guillomovitch> 1.4.1-1.mga4
+ Revision: 432768
- new version

* Sat Jan 12 2013 umeabot <umeabot> 1.3.2-2.mga3
+ Revision: 352519
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 13 2012 luigiwalser <luigiwalser> 1.3.2-1.mga3
+ Revision: 281028
- 1.3.2

* Fri Dec 16 2011 wally <wally> 1.3.1-2.mga2
+ Revision: 182610
- drop .la files (mga#3788)

* Fri Jul 08 2011 ahmad <ahmad> 1.3.1-1.mga2
+ Revision: 120201
- Update to 1.3.1
- Bump BR libgpg-error-devel version

* Sat Jan 15 2011 mikala <mikala> 1.3.0-2.mga1
+ Revision: 18620
- Drop mdk macros
- Remove BuildRoot
- imported package gpgme


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1.3.0-2mdv2011.0
+ Revision: 605495
- rebuild

* Mon Jan 11 2010 Lonyai Gergely <aleph@mandriva.org> 1.3.0-1mdv2010.1
+ Revision: 489739
- 1.3.0

* Tue Jun 30 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.2.0-1mdv2010.0
+ Revision: 390789
- Update  to gpgme 1.2.0

* Sun Jan 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.8-1mdv2009.1
+ Revision: 331039
- update to new version 1.1.8

* Sun Nov 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.7-1mdv2009.1
+ Revision: 303835
- update to new version 1.1.7
- fix ur for Source0

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 1.1.6-2mdv2009.0
+ Revision: 221100
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Jan 23 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.6-1mdv2008.1
+ Revision: 157125
- new license policy
- do not package COPYING files
- spec file clean
- new version

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.1.5-2mdv2008.1
+ Revision: 136461
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 24 2007 Andreas Hasenack <andreas@mandriva.com> 1.1.5-2mdv2008.0
+ Revision: 92576
- added missing buildrequires (glib2-devel) + rebuild

* Wed Aug 01 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.5-1mdv2008.0
+ Revision: 57324
- new devel library policy
- make use of %%{major}
- add %%check section
- new version


* Wed Mar 14 2007 Andreas Hasenack <andreas@mandriva.com> 1.1.4-1mdv2007.1
+ Revision: 143695
- updated to version 1.1.4
- updated to version 1.1.3
- removed pthread patch, already applied
- added lisp files to devel package

* Wed Nov 29 2006 Andreas Hasenack <andreas@mandriva.com> 1.1.2-3mdv2007.1
+ Revision: 88736
- fix gpgme-config (#27380)
- Import gpgme

* Tue Aug 29 2006 Oden Eriksson <oeriksson@mandrakesoft.com> 1.1.2-2
- fix deps

* Sun Jul 02 2006 Charles A Edwards <eslrahc@mandriva.org> 1.1.2-1mdv2007.0
- 1.1.2
- mkrel 
- src url

* Thu Aug 25 2005 Abel Cheung <deaddog@mandriva.org> 1.0.3-1mdk
- New release 1.0.3

* Sat Apr 16 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 1.0.2-1mdk
- 1.0.2
- fix deps and conditional %%multiarch
- run the test suite
- fix requires-on-release

* Mon Jan 03 2005 Goetz Waschk <waschk@linux-mandrake.com> 1.0.1-1mdk
- New release 1.0.1

* Thu Oct 21 2004 Götz Waschk <waschk@linux-mandrake.com> 1.0.0-1mdk
- fix source URL
- New release 1.0.0

* Fri Aug 20 2004 Abel Cheung <deaddog@deaddog.org> 0.9.0-1mdk
- New version
- Disable test, some gpgsm tests appears to need fixing

* Fri May 21 2004 Abel Cheung <deaddog@deaddog.org> 0.4.7-1mdk
- New version

